@@ -1,11 +1,10 @@
 package Text::Template::Simple::Base::Parser;
 use strict;
 use vars qw($VERSION);
-use Carp qw( croak );
 use Text::Template::Simple::Util;
 use Text::Template::Simple::Constants;
 
-$VERSION = '0.62_06';
+$VERSION = '0.62_07';
 
 # internal code templates
 my %INTERNAL = (
@@ -68,8 +67,8 @@ my %INTERNAL = (
 
 sub _internal {
    my $self = shift;
-   my $id   = shift            || croak "_internal(): id is missing";
-   my $rv   = $INTERNAL{ $id } || croak "_internal(): id is invalid";
+   my $id   = shift            || fatal('tts.base.parser._internal.id');
+   my $rv   = $INTERNAL{ $id } || fatal('tts.base.parser._internal.id');
    return $rv;
 }
 
@@ -176,11 +175,12 @@ sub _parse {
 
    $self->[FILENAME] ||= '<ANON>';
 
-   if ( $inside ) {
-      my $type = $inside > 0 ? 'opening' : 'closing';
-      my $tmpl = "%d unbalanced %s delimiter(s) in template %s";
-      croak sprintf( $tmpl, abs($inside), $type, $self->[FILENAME] );
-   }
+   fatal(
+      'tts.base.parser._parse.unbalanced',
+      abs($inside),
+      ($inside > 0 ? 'opening' : 'closing'),
+      $self->[FILENAME]
+   ) if $inside;
 
    return $self->_wrapper( $code, $cache_id, $faker, $map_keys );
 }
@@ -355,8 +355,12 @@ Private module.
 
 =head1 DESCRIPTION
 
-This document describes version 0.62_06 of Text::Template::Simple::Base::Parser
-released on 21 October 2008.
+This document describes version C<0.62_07> of C<Text::Template::Simple::Base::Parser>
+released on C<5 April 2009>.
+
+B<WARNING>: This version of the module is part of a
+developer (beta) release of the distribution and it is
+not suitable for production use.
 
 Private module.
 
@@ -379,7 +383,8 @@ If the previous or next is not raw, nothing will happen. You need to swap sides
 when handling the chomping. i.e.: left chomping affects the right side of the
 RAW, and right chomping affects the left side of the RAW. _chomp() method in
 the parser swaps sides to handle chomping.
-See Text::Template::Simple::Tokenizer to see how pre-parsing happens.
+See Text::Template::Simple::Tokenizer to have an idea on how pre-parsing
+happens.
 
 =end CHOMPING
 
