@@ -2,23 +2,19 @@ package Text::Template::Simple::Tokenizer;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '0.62_06';
+$VERSION = '0.62_07';
 
 use constant CMD_CHAR             =>  0;
 use constant CMD_ID               =>  1;
-use constant CMD_CB               =>  2; # callback
-
+use constant CMD_CB               =>  2; # callbacks
 use constant ID_DS                =>  0;
 use constant ID_DE                =>  1;
 use constant ID_PRE_CHOMP         =>  2;
 use constant ID_POST_CHOMP        =>  3;
-
 use constant SUBSTR_OFFSET_FIRST  =>  0;
 use constant SUBSTR_OFFSET_SECOND =>  1;
 use constant SUBSTR_LENGTH        =>  1;
-
-use Carp qw( croak );
-use Text::Template::Simple::Util      qw( LOG );
+use Text::Template::Simple::Util      qw( LOG fatal );
 use Text::Template::Simple::Constants qw( :chomp :directive :token );
 
 my @COMMANDS = ( # default command list
@@ -35,8 +31,8 @@ sub new {
    my $class = shift;
    my $self  = [];
    bless $self, $class;
-   $self->[ID_DS]         = shift || croak "Start delimiter is missing";
-   $self->[ID_DE]         = shift || croak "End delimiter is missing";
+   $self->[ID_DS]         = shift || fatal('tts.tokenizer.new.ds');
+   $self->[ID_DE]         = shift || fatal('tts.tokenizer.new.de');
    $self->[ID_PRE_CHOMP]  = shift || CHOMP_NONE;
    $self->[ID_POST_CHOMP] = shift || CHOMP_NONE;
    $self;
@@ -45,12 +41,12 @@ sub new {
 sub tokenize {
    # compile the template into a tree and optimize
    my $self       = shift;
-   my $tmp        = shift || croak "tokenize(): Template string is missing";
+   my $tmp        = shift || fatal('tts.tokenizer.tokenize.tmp');
    my $map_keys   = shift;
    my($ds, $de)   = ($self->[ID_DS], $self->[ID_DE]);
    my($qds, $qde) = map { quotemeta $_ } $ds, $de;
 
-   my(@tokens, $inside, $last, $i, $j);
+   my(@tokens, $inside);
 
    OUT_TOKEN: foreach my $i ( split /($qds)/, $tmp ) {
 
@@ -340,8 +336,12 @@ Text::Template::Simple::Tokenizer - Tokenizer
 
 =head1 DESCRIPTION
 
-This document describes version 0.62_06 of Text::Template::Simple::Tokenizer
-released on 21 October 2008.
+This document describes version C<0.62_07> of C<Text::Template::Simple::Tokenizer>
+released on C<5 April 2009>.
+
+B<WARNING>: This version of the module is part of a
+developer (beta) release of the distribution and it is
+not suitable for production use.
 
 Tokenizes the input with the defined delimiter pair.
 
